darkhistory.utilities.log\_1\_plus\_x
=====================================

.. currentmodule:: darkhistory.utilities

.. autofunction:: log_1_plus_x

.. rubric:: Footnotes

.. [1] David Goldberg. 1991. What every computer scientist should know about floating-point arithmetic. ACM Comput. Surv. 23, 1 (March 1991), 5-48. 

